pub enum InputSequence {
Raw(Vec<u8>),
AbortAndRaw(Vec<u8>),
AbortAndCommand(String),
}Variants
Raw(Vec<u8>)
!!!WARNING!!!
Is is very rare to need a raw input sequence. Please ensure you absolutely know what you are doing before using this method.
AbortAndRaw(Vec<u8>)
This will send the equivalent of Ctrl+C to the terminal process. Before adding your input.
AbortAndCommand(String)
This will send the equivalent of Ctrl+C to the terminal process, add your command and finally send a newline.
Be aware that your command will not be sanitized!.