LocalTerminal

Struct LocalTerminal 

pub struct LocalTerminal { /* private fields */ }

Implementations

Source

impl LocalTerminal

pub fn start( key_filter: impl 'static + Fn(&Key, &Modifiers) -> bool, ) -> (Self, Task<Message>)

pub fn style(self, style: Style) -> Self

pub fn set_style(&mut self, style: Style)

pub fn update(&mut self, message: Message) -> Action

pub fn view<'a>(&'a self) -> Element<'a, Message>

pub fn get_title(&self) -> &str

pub fn focus<T>(&self) -> Task<T>
where T: Send + 'static,

pub fn inject_input(&self, input: InputSequence) -> Task<Message>

!!!WARNING!!!

injected input will be directly injected into the stdin of the terminal process. If the user has typed something, that input will still be there! When writing commands manually, you’ll need to ensure that they are not influenced by what the user has typed and you will also have to handle key encoding and control characters yourself.